/*
 * Copyright 1998-2001, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
 *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
 * 
 * This file is part of the Notre Dame LAM implementation of MPI.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame LAM implementation of MPI along with the software; see the file
 * LICENSE.  If not, contact Office of Research, University of Notre
 * Dame, Notre Dame, IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *	Ohio Trollius
 *	Copyright 1997 The Ohio State University
 *	NJN
 *
 *	$Id: wcreatekey.c,v 1.1 2001/02/03 20:51:49 arodrig6 Exp $
 *
 *	Function:	- create a window attribute key
 *	Accepts:	- copy function
 *			- delete function
 *			- key (out)
 *			- extra state info
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>

/*@
MPI_Win_create_keyval - Create a window attribute key

Input Parameters:
+ cpyfunc - copy callback function for win_keyval (function) 
. delfunc - delete callback function for win_keyval (function) 
- extra - extra state for callback functions 

Output Parameter:
+ key - key value for future access (integer) 

.N fortran

.N Errors
.N MPI_SUCCESS
.N MPI_ERR_OTHER
.N MPI_ERR_ARG

.seealso MPI_Win_free_keyval(3), MPI_Win_get_attr(3), MPI_Win_set_attr(3), MPI_Win_delete_attr(3)

.N WEB
  @*/


int MPI_Win_create_keyval(MPI_Win_copy_attr_function *cpyfunc,
			  MPI_Win_delete_attr_function *delfunc,
			  int *key,
			  void *extra)
{
        int 		err;

	lam_initerr_m();
	lam_setfunc_m(BLKMPIWINCREATEKEYVAL);

	err = lam_keyval_create((void_fn *) cpyfunc, (void_fn *) delfunc, 
				key, extra, LAM_AKWIN);

	if (err != MPI_SUCCESS) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIWINCREATEKEYVAL, err));
	}

	lam_resetfunc_m(BLKMPIWINCREATEKEYVAL);
	return(MPI_SUCCESS);
}
